@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-01-07'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -179,7 +179,9 @@ sub munge_files {
 
 __PACKAGE__->meta->make_immutable;
 1;
-# ABSTRACT: Do various stuffs for Bencher-Scenario-* distribution
+# ABSTRACT: Plugin to use when building Bencher::Scenario::* distribution
+
+
 
 __END__
 
@@ -189,11 +191,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Bencher::Scenario - Do various stuffs for Bencher-Scenario-* distribution
+Dist::Zilla::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Scenario::* distribution
 
 =head1 VERSION
 
-This document describes version 0.09 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-01-07.
+This document describes version 0.10 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -203,15 +205,14 @@ In F<dist.ini>:
 
 =head1 DESCRIPTION
 
-This plugin is meant to be use when building C<Bencher-Scenario-*> distribution
-(e.g.: L<Bencher::Scenario::SetOperationModules>,
-L<Bencher::Scenario::Serializers>). Currently what it does are the following:
+This plugin is to be used when building C<Bencher::Scenario::*> distribution.
+It currently dos the following:
 
 =over
 
 =item * Add the benchmarked modules as RuntimeRequires prereqs
 
-=item * Add Bencher to TestRequires prereq and add test files C<t/bench.t-*>
+=item * Add Bencher (the currently installed version during building) to TestRequires prereq and add test files C<t/bench.t-*>
 
 =item * Fill-in ABSTRACT from scenario's summary
 
@@ -253,3 +254,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
